@@ -2,18 +2,13 @@ import subprocess
 import sys
 from pathlib import Path
 
-import nox  # type: ignore
+import nox
 
 PYTHON_ALL_VERSIONS = ["3.12", "3.11", "3.10", "3.9", "3.8"]
 PYTHON_DEFAULT_VERSION = "3.12"
-DOC_DEPENDENCIES = [".", "jinja2", "mkdocs", "mkdocs-material"]
-MAN_DEPENDENCIES = [".", "argparse-manpage[setuptools]"]
-LINT_DEPENDENCIES = [
-    "mypy==1.7.1",
-    "packaging>=20.0",
-    "ruff==0.1.6",
-    "types-jinja2",
-]
+DOC_DEPENDENCIES = ["jinja2", "mkdocs", "mkdocs-material", "mkdocs-gen-files"]
+MAN_DEPENDENCIES = ["argparse-manpage[setuptools]"]
+TEST_DEPENDENCIES = ["pytest", "pypiserver[passlib]", 'setuptools; python_version>="3.12"', "pytest-cov"]
 # Packages whose dependencies need an intact system PATH to compile
 # pytest setup clears PATH.  So pre-build some wheels to the pip cache.
 PREBUILD_PACKAGES = {"all": ["jupyter==1.0.0"], "macos": [], "unix": [], "win": []}
@@ -21,23 +16,14 @@ PIPX_TESTS_CACHE_DIR = Path("./.pipx_tests/package_cache")
 PIPX_TESTS_PACKAGE_LIST_DIR = Path("testdata/tests_packages")
 
 # Platform logic
-if sys.platform == "darwin":
-    PLATFORM = "macos"
-elif sys.platform == "win32":
-    PLATFORM = "win"
-else:
-    PLATFORM = "unix"
-
-# Set nox options
-if PLATFORM == "win":
-    # build_docs fail on Windows, even if `chcp.com 65001` is used
-    nox.options.sessions = ["tests", "lint", "build_man"]
-else:
-    nox.options.sessions = ["tests", "lint", "build_docs", "build_man"]
+PLATFORM = {"darwin": "macos", "win32": "win"}.get(sys.platform, "unix")
+nox.options.sessions = ["tests", "lint", "build_docs", "zipapp"]
+if PLATFORM != "win":  # build_docs fail on Windows, even if `chcp.com 65001` is used
+    nox.options.sessions.append("build_man")
 nox.options.reuse_existing_virtualenvs = True
 
 
-def prebuild_wheels(session, prebuild_dict):
+def prebuild_wheels(session: nox.Session, prebuild_dict) -> None:
     prebuild_list = prebuild_dict.get("all", []) + prebuild_dict.get(PLATFORM, [])
 
     session.install("wheel")
@@ -48,205 +34,127 @@ def prebuild_wheels(session, prebuild_dict):
         session.run("pip", "wheel", f"--wheel-dir={wheel_dir}", prebuild, silent=True)
 
 
-def has_changes():
-    status = (
-        subprocess.run("git status --porcelain", shell=True, check=True, stdout=subprocess.PIPE).stdout.decode().strip()
-    )
-    return len(status) > 0
-
-
-def get_branch():
-    return (
-        subprocess.run(
-            "git rev-parse --abbrev-ref HEAD",
-            shell=True,
-            check=True,
-            stdout=subprocess.PIPE,
-        )
-        .stdout.decode()
-        .strip()
-    )
-
-
-def on_main_no_changes(session):
-    if has_changes():
+def on_main_no_changes(session: nox.Session) -> None:
+    if len(subprocess.check_output(["git", "status", "--porcelain"], text=True).strip()) > 0:  # has changes
         session.error("All changes must be committed or removed before publishing")
-    branch = get_branch()
+    branch = subprocess.check_output(["git", "rev-parse", "--abbrev-ref", "HEAD"], text=True).strip()
     if branch != "main":
         session.error(f"Must be on 'main' branch. Currently on {branch!r} branch")
 
 
-@nox.session(python=PYTHON_ALL_VERSIONS)
-def refresh_packages_cache(session):
-    """Populate .pipx_tests/package_cache"""
-    print("Updating local tests package spec file cache...")
-    PIPX_TESTS_CACHE_DIR.mkdir(exist_ok=True, parents=True)
-    session.run(
-        "python",
-        "scripts/update_package_cache.py",
-        str(PIPX_TESTS_PACKAGE_LIST_DIR),
-        str(PIPX_TESTS_CACHE_DIR),
-    )
-
-
-def tests_with_options(session, net_pypiserver):
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
+def tests_with_options(session: nox.Session, *, net_pypiserver: bool) -> None:
     prebuild_wheels(session, PREBUILD_PACKAGES)
-    session.install("-e", ".", "pytest", "pytest-cov")
-    tests = session.posargs or ["tests"]
-
+    session.install("-e", ".", *TEST_DEPENDENCIES)
+    test_dir = session.posargs or ["tests"]
     if net_pypiserver:
         pypiserver_option = ["--net-pypiserver"]
     else:
-        session.install("pypiserver[passlib]", 'setuptools; python_version>="3.12"')
         refresh_packages_cache(session)
         pypiserver_option = []
-
-    session.run("pytest", *pypiserver_option, "--cov=pipx", "--cov-report=", *tests)
+    session.run("pytest", *pypiserver_option, "--cov=pipx", "--cov-report=", *test_dir)
     session.notify("cover")
 
 
 @nox.session(python=PYTHON_ALL_VERSIONS)
-def tests_internet(session):
-    """Tests using internet pypi only"""
-    tests_with_options(session, net_pypiserver=True)
-
-
-@nox.session(python=PYTHON_ALL_VERSIONS)
-def tests(session):
+def tests(session: nox.Session) -> None:
     """Tests using local pypiserver only"""
     tests_with_options(session, net_pypiserver=False)
 
 
-@nox.session(python=PYTHON_ALL_VERSIONS)
-def test_all_packages(session):
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install("-e", ".", "pytest")
-    tests = session.posargs or ["tests"]
-    session.run(
-        "pytest",
-        "-v",
-        "--tb=no",
-        "--show-capture=no",
-        "--net-pypiserver",
-        "--all-packages",
-        *tests,
-    )
-
-
 @nox.session
-def cover(session):
+def cover(session: nox.Session) -> None:
     """Coverage analysis"""
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
     session.install("coverage")
     session.run("coverage", "report", "--show-missing", "--fail-under=70")
     session.run("coverage", "erase")
 
 
+@nox.session
+def zipapp(session: nox.Session) -> None:
+    """Build a zipapp with shiv"""
+    session.install("shiv")
+    session.run("shiv", "-c", "pipx", "-o", "./pipx.pyz", ".")
+    session.run("./pipx.pyz", "--version", external=True)
+
+
 @nox.session(python=PYTHON_DEFAULT_VERSION)
 def lint(session):
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install(*LINT_DEPENDENCIES)
-    files = [str(Path("src") / "pipx"), "tests", "scripts"] + [str(p) for p in Path(".").glob("*.py")]
-    session.run("ruff", *files)
-    session.run(
-        "mypy",
-        "--strict-equality",
-        "--no-implicit-optional",
-        "--warn-unused-ignores",
-        "--check-untyped-defs",
-        *files,
-    )
+    session.run("python", "-m", "pip", "install", "pre-commit")
+    session.run("pre-commit", "run", "--all-files")
 
 
 @nox.session(python=PYTHON_ALL_VERSIONS)
-def develop(session):
+def develop(session: nox.Session) -> None:
+    """Create a develop environment."""
     session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install(*DOC_DEPENDENCIES, *LINT_DEPENDENCIES)
-    session.install("-e", ".", "pytest", "pypiserver[passlib]", 'setuptools; python_version>="3.12"')
+    session.install(*DOC_DEPENDENCIES, *TEST_DEPENDENCIES, *MAN_DEPENDENCIES, "-e", ".", "nox")
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
-def build(session):
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
+def build(session: nox.Session) -> None:
+    """Build the wheel and source distribution for the project."""
     session.install("build")
     session.run("rm", "-rf", "dist", "build", external=True)
     session.run("python", "-m", "build")
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
-def publish(session):
+def publish(session: nox.Session) -> None:
+    """Publish the package to PyPI."""
     on_main_no_changes(session)
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
     session.install("twine")
     build(session)
-    print("REMINDER: Has the changelog been updated?")
     session.run("python", "-m", "twine", "upload", "dist/*")
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
-def build_docs(session):
+def build_docs(session: nox.Session) -> None:
     site_dir = session.posargs or ["site/"]
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install(*DOC_DEPENDENCIES)
+    session.install(*DOC_DEPENDENCIES, ".")
     session.env["PIPX__DOC_DEFAULT_PYTHON"] = "typically the python used to execute pipx"
-    session.run("python", "scripts/generate_docs.py")
     session.run("mkdocs", "build", "--strict", "--site-dir", *site_dir)
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
-def watch_docs(session):
-    session.install(*DOC_DEPENDENCIES)
-    session.run("python", "scripts/generate_docs.py")
+def watch_docs(session: nox.Session) -> None:
+    session.install(*DOC_DEPENDENCIES, ".")
     session.run("mkdocs", "serve", "--strict")
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
-def build_man(session):
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install(*MAN_DEPENDENCIES)
+def build_man(session: nox.Session) -> None:
+    session.install(*MAN_DEPENDENCIES, ".")
     session.env["PIPX__DOC_DEFAULT_PYTHON"] = "typically the python used to execute pipx"
     session.run("python", "scripts/generate_man.py")
 
 
-@nox.session(python=PYTHON_DEFAULT_VERSION)
-def pre_release(session):
-    on_main_no_changes(session)
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install("mypy")
-    if session.posargs:
-        new_version = session.posargs[0]
-    else:
-        new_version = input("Enter new version: ")
-    session.run("python", "scripts/pipx_prerelease.py", new_version)
-    session.run("git", "--no-pager", "diff", external=True)
-    print("")
-    session.log(
-        "If `git diff` above looks ok, execute the following command:\n\n"
-        f"    git commit -a -m 'Pre-release {new_version}.'\n"
-    )
-
-
-@nox.session(python=PYTHON_DEFAULT_VERSION)
-def post_release(session):
-    on_main_no_changes(session)
-    session.run("python", "-m", "pip", "install", "--upgrade", "pip")
-    session.install("mypy")
-    session.run("python", "scripts/pipx_postrelease.py")
-    session.run("git", "--no-pager", "diff", external=True)
-    print("")
-    session.log(
-        "If `git diff` above looks ok, execute the following command:\n\n" "    git commit -a -m 'Post-release.'\n"
-    )
+@nox.session(python=PYTHON_ALL_VERSIONS)
+def refresh_packages_cache(session: nox.Session) -> None:
+    """Populate .pipx_tests/package_cache"""
+    print("Updating local tests package spec file cache...")
+    PIPX_TESTS_CACHE_DIR.mkdir(exist_ok=True, parents=True)
+    script = "scripts/update_package_cache.py"
+    session.run("python", script, str(PIPX_TESTS_PACKAGE_LIST_DIR), str(PIPX_TESTS_CACHE_DIR))
 
 
 @nox.session(python=PYTHON_ALL_VERSIONS)
-def create_test_package_list(session):
+def create_test_package_list(session: nox.Session) -> None:
+    """Update the list of packages needed for running the test suite."""
     session.run("python", "-m", "pip", "install", "--upgrade", "pip")
     output_dir = session.posargs[0] if session.posargs else str(PIPX_TESTS_PACKAGE_LIST_DIR)
-    session.run(
-        "python",
-        "scripts/list_test_packages.py",
-        str(PIPX_TESTS_PACKAGE_LIST_DIR / "primary_packages.txt"),
-        output_dir,
-    )
+    primary = str(PIPX_TESTS_PACKAGE_LIST_DIR / "primary_packages.txt")
+    session.run("python", "scripts/list_test_packages.py", primary, output_dir)
+
+
+@nox.session(python=PYTHON_ALL_VERSIONS)
+def tests_internet(session: nox.Session) -> None:
+    """Tests using internet pypi only"""
+    tests_with_options(session, net_pypiserver=True)
+
+
+@nox.session(python=PYTHON_ALL_VERSIONS)
+def test_all_packages(session: nox.Session) -> None:
+    """A more in depth but slower test suite."""
+    session.install("-e", ".", *TEST_DEPENDENCIES)
+    test_dir = session.posargs or ["tests"]
+    session.run("pytest", "-v", "--tb=no", "--show-capture=no", "--net-pypiserver", "--all-packages", *test_dir)
